/**
  ******************************************************************************
  * @file    fm33g0xx_dma.c
  * @author  FM33g0xx Application Team
  * @version V0.3.00G
  * @date    08-31-2018
  * @brief   This file provides firmware functions to manage the following 
  *
*/

/* Includes ------------------------------------------------------------------*/
#include "fm33g0xx_dma.h" 

/** @addtogroup fm33g0xx_StdPeriph_Driver
  * @{
  */

/** @defgroup DMA 
  * @brief DMA driver modules
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/** @defgroup DMA_Private_Functions
  * @{
  */ 



/********************************
DMAܿƺ
: DMAȫʹ
룺ENABLE/DISABLE	DMAʹ/DMAر	
: 
********************************/
void DMA_GLOBALCTRL_DMAEN_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		DMA->GLOBALCTRL |= (DMA_GLOBALCTRL_DMAEN_Msk);
	}
	else
	{
		DMA->GLOBALCTRL &= ~(DMA_GLOBALCTRL_DMAEN_Msk);
	}
}
/********************************
DMAܿƺ
: ȡDMAȫʹ
룺
: ENABLE/DISABLE	DMAʹ/DMAر	
********************************/
FunState DMA_GLOBALCTRL_DMAEN_Getable(void)
{
	if (DMA->GLOBALCTRL & (DMA_GLOBALCTRL_DMAEN_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}


/********************************
DMAܿƺ
: Channelx 䳤
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			SetValue: 0-1fff(䳤ΪSetValue+1)
: 
********************************/
void DMA_CHxCTRL_TSIZE_Set(DMA_CH_Type CHx, uint32_t SetValue)
{
	uint32_t *pREG;
	uint32_t tmpreg;    
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);//DMA->CH0CTRL;
	
    SetValue <<= DMA_CHxCTRL_TSIZE_Pos;//ֹ
	tmpreg = *pREG;
	tmpreg &= ~(DMA_CHxCTRL_TSIZE_Msk);
	tmpreg |= (SetValue&DMA_CHxCTRL_TSIZE_Msk);
	*pREG = tmpreg;
}
/********************************
DMAܿƺ
: ȡChannelx 䳤
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: tmpsize: 0-1fff(䳤Ϊtmpsize+1)
********************************/
uint32_t DMA_CHxCTRL_TSIZE_Get(DMA_CH_Type CHx)
{
	uint32_t *pREG;
    uint32_t tmpsize;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	
    tmpsize = (*pREG & DMA_CHxCTRL_TSIZE_Msk);
    tmpsize >>= DMA_CHxCTRL_TSIZE_Pos;
	return tmpsize;
}

/********************************
DMAܿƺ
: Channelx ȼ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			DMA_CHxCTRL_PRI_LOW				ȼ
			/DMA_CHxCTRL_PRI_MEDIUM		ȼ
			/DMA_CHxCTRL_PRI_HIGH			ȼ
			/DMA_CHxCTRL_PRI_VERY_HIGH	ȼ
: 
********************************/
void DMA_CHxCTRL_PRI_Set(DMA_CH_Type CHx, uint32_t SetValue)
{
	uint32_t *pREG;
	uint32_t tmpreg;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	
	tmpreg = *pREG;
	tmpreg &= ~(DMA_CHxCTRL_PRI_Msk);
	tmpreg |= (SetValue&DMA_CHxCTRL_PRI_Msk);
	*pREG = tmpreg;
}
/********************************
DMAܿƺ
: ȡChannelx ȼ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: DMA_CHxCTRL_PRI_LOW				ȼ
			/DMA_CHxCTRL_PRI_MEDIUM		ȼ
			/DMA_CHxCTRL_PRI_HIGH			ȼ
			/DMA_CHxCTRL_PRI_VERY_HIGH	ȼ
********************************/
uint32_t DMA_CHxCTRL_PRI_Get(DMA_CH_Type CHx)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	return (*pREG & DMA_CHxCTRL_PRI_Msk);
}

/********************************
DMAܿƺ
: Channelx RAMַ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			DMA_CHxCTRL_INC_DEC			ַݼ
			/DMA_CHxCTRL_INC_INC		ַ
: 
********************************/
void DMA_CHxCTRL_INC_Set(DMA_CH_Type CHx, uint32_t SetValue)
{
	uint32_t *pREG;
	uint32_t tmpreg;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	
	tmpreg = *pREG;
	tmpreg &= ~(DMA_CHxCTRL_INC_Msk);
	tmpreg |= (SetValue&DMA_CHxCTRL_INC_Msk);
	*pREG = tmpreg;
}
/********************************
DMAܿƺ
: ȡChannelx RAMַ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: DMA_CHxCTRL_INC_DEC			ַݼ
			/DMA_CHxCTRL_INC_INC		ַ
********************************/
uint32_t DMA_CHxCTRL_INC_Get(DMA_CH_Type CHx)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	return (*pREG & DMA_CHxCTRL_INC_Msk);
}

/********************************
DMAܿƺ
: Channelx ͨѡ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			DMA_CH0CTRL_CH0SSEL_ET4_CAP				ET4ͨ
			/DMA_CH0CTRL_CH0SSEL_ET2_CAP			ET2ͨ
			/DMA_CH0CTRL_CH0SSEL_BT2_CAP			BT2ͨ
			/DMA_CH0CTRL_CH0SSEL_ET3_CAP			ET3ͨ
			/DMA_CH0CTRL_CH0SSEL_BT1_CAP			BT1ͨ
			/DMA_CH0CTRL_CH0SSEL_CRC_OUT			CRCͨ
			/DMA_CH0CTRL_CH0SSEL_AES_IN				AESͨ
			/DMA_CH0CTRL_CH0SSEL_ADC_OUT			ADCͨ
: 
********************************/
void DMA_CHxCTRL_SSEL_Set(DMA_CH_Type CHx, uint32_t SetValue)
{
	uint32_t *pREG;
	uint32_t tmpreg;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	
	tmpreg = *pREG;
	tmpreg &= ~(DMA_CHxCTRL_SSEL_Msk);
	tmpreg |= (SetValue&DMA_CHxCTRL_SSEL_Msk);
	*pREG = tmpreg;
}
/********************************
DMAܿƺ
: ȡChannelx ͨѡ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: DMA_CH0CTRL_CH0SSEL_ET4_CAP				ET4ͨ
			/DMA_CH0CTRL_CH0SSEL_ET2_CAP			ET2ͨ
			/DMA_CH0CTRL_CH0SSEL_BT2_CAP			BT2ͨ
			/DMA_CH0CTRL_CH0SSEL_ET3_CAP			ET3ͨ
			/DMA_CH0CTRL_CH0SSEL_BT1_CAP			BT1ͨ
			/DMA_CH0CTRL_CH0SSEL_CRC_OUT			CRCͨ
			/DMA_CH0CTRL_CH0SSEL_AES_IN				AESͨ
			/DMA_CH0CTRL_CH0SSEL_ADC_OUT			ADCͨ
********************************/
uint32_t DMA_CHxCTRL_SSEL_Get(DMA_CH_Type CHx)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	return (*pREG & DMA_CHxCTRL_SSEL_Msk);
}

/********************************
DMAܿƺ
: Channelx жʹ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			ENABLE/DISABLE	ʹܴж/رմж		
: 
********************************/
void DMA_CHxCTRL_FTIE_Setable(DMA_CH_Type CHx, FunState NewState)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	if (NewState == ENABLE)
	{
		*pREG |= (DMA_CHxCTRL_FTIE_Msk);
	}
	else
	{
		*pREG &= ~(DMA_CHxCTRL_FTIE_Msk);
	}
}
/********************************
DMAܿƺ
: ȡChannelx жʹ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: ENABLE/DISABLE	ʹܴж/رմж	
********************************/
FunState DMA_CHxCTRL_FTIE_Getable(DMA_CH_Type CHx)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	if (*pREG & (DMA_CHxCTRL_FTIE_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
DMAܿƺ
: Channelx ̴жʹ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			ENABLE/DISABLE	ʹܰж/رհж		
: 
********************************/
void DMA_CHxCTRL_HTIE_Setable(DMA_CH_Type CHx, FunState NewState)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	if (NewState == ENABLE)
	{
		*pREG |= (DMA_CHxCTRL_HTIE_Msk);
	}
	else
	{
		*pREG &= ~(DMA_CHxCTRL_HTIE_Msk);
	}
}
/********************************
DMAܿƺ
: Channelx ̴жʹ
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: ENABLE/DISABLE	ʹܰж/رհж
********************************/
FunState DMA_CHxCTRL_HTIE_Getable(DMA_CH_Type CHx)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	if (*pREG & (DMA_CHxCTRL_HTIE_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
DMAܿƺ
: Channelx 
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
			ENABLE/DISABLE	CHx DMA/CHx DMAܹر
: 
********************************/
void DMA_CHxCTRL_EN_Setable(DMA_CH_Type CHx, FunState NewState)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + CHx*8);
	if (NewState == ENABLE)
	{
		*pREG |= (DMA_CHxCTRL_EN_Msk);
	}
	else
	{
		*pREG &= ~(DMA_CHxCTRL_EN_Msk);
	}
}

/********************************
DMAܿƺ
: Channelx RAMַָ(DMAǰ˼ĴдRAMĿַDMA˼ĴDMAԼ)
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6)
SetValue:16bit ַ
: 
********************************/
void DMA_CHxRAMAD_Write(DMA_CH_Type CHx, uint32_t SetValue)
{
	uint32_t *pREG;
	
	pREG = (uint32_t *)(0x40000404 + 4 + CHx*8);
	*pREG = SetValue;
}

//uint32_t DMA_CHxRAMAD_Read(DMA_CH_Type CHx)
//{
//	uint32_t *pREG;
//	
//	pREG = (uint32_t *)(0x40000404 + 4 + CHx*8);
//	return (*pREG);
//}



/* Channel7FLASHַָ غ */
/********************************
DMAܿƺ
: Channel7 FLASHַָ(DMAǰ˼ĴдFlashĿַDMA˼ĴDMAԼ)
룺CHx(DMA_CH7 = 7)
SetValue:17bit ַ
: 
********************************/
void DMA_CH7FLSAD_Write(uint32_t SetValue)
{
//	DMA->CH7FLSAD = SetValue;
	DMA->CH7FLSAD = SetValue>>2;//CH7flashֵַַ˴2bitԱʹʱʹַͨ
}

//uint32_t DMA_CH7FLSAD_Read(void)
//{
//	return (DMA->CH7FLSAD);
//}


/********************************
DMAܿƺ
: Channel7 RAMַָ(DMAǰ˼ĴдRAMĿַDMA˼ĴDMAԼ)
룺CHx(DMA_CH7 = 7)
SetValue:14bit ַ
: 
********************************/
void DMA_CH7RAMAD_Write(uint32_t SetValue)
{
//	DMA->CH7RAMAD = SetValue;
	DMA->CH7RAMAD = SetValue>>2;//CH7RAMֵַַ˴2bitԱʹʱʹַͨ
}

//uint32_t DMA_CH7RAMAD_Read(void)
//{
//	return (DMA->CH7RAMAD);
//}


/********************************
DMAܿƺ
: Channelx ̱־
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: 
********************************/
void DMA_CHSTATUS_DMACHxHT_Clr(DMA_CH_Type CHx)
{
	DMA->CHSTATUS = (0x1U<<CHx);
}
/********************************
DMAܿƺ
: ȡChannelx ̱־
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: SET/RESET		Ӧ̴ͨ/Ӧ̴ͨδ
********************************/
FlagStatus DMA_CHSTATUS_DMACHxHT_Chk(DMA_CH_Type CHx)
{
	if (DMA->CHSTATUS & (0x1U<<CHx))
	{
		return SET;
	}
	else
	{
		return RESET;
	}
}

/********************************
DMAܿƺ
: Channelx ɱ־
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: 
********************************/
void DMA_CHSTATUS_DMACHxFT_Clr(DMA_CH_Type CHx)
{
	DMA->CHSTATUS = (0x100U<<CHx);
}
/********************************
DMAܿƺ
: ȡChannelx ɱ־
룺CHx(DMA_CH0 = 0, DMA_CH1 = 1, DMA_CH2 = 2, DMA_CH3 = 3, DMA_CH4 = 4, DMA_CH5 = 5, DMA_CH6 = 6, DMA_CH7 = 7)
: SET/RESET		Ӧͨ/Ӧͨδ
********************************/
FlagStatus DMA_CHSTATUS_DMACHxFT_Chk(DMA_CH_Type CHx)
{
	if (DMA->CHSTATUS & (0x100U<<CHx))
	{
		return SET;
	}
	else
	{
		return RESET;
	}
}
/********************************
DMAܿƺ
: DMAܳʼȱʡ
룺
: 
********************************/
void DMA_Deinit(void)
{
	DMA->GLOBALCTRL = 0x00000000;
	DMA->CH0CTRL = 0x00000000;
	DMA->CH0RAMAD = 0x00000000;
	DMA->CH1CTRL = 0x00000000;
	DMA->CH1RAMAD = 0x00000000;
	DMA->CH2CTRL = 0x00000000;
	DMA->CH2RAMAD = 0x00000000;
	DMA->CH3CTRL = 0x00000000;
	DMA->CH3RAMAD = 0x00000000;
	DMA->CH4CTRL = 0x00000000;
	DMA->CH4RAMAD = 0x00000000;
	DMA->CH5CTRL = 0x00000000;
	DMA->CH5RAMAD = 0x00000000;
	DMA->CH6CTRL = 0x00000000;
	DMA->CH6RAMAD = 0x00000000;
	DMA->CH7CTRL = 0x00000000;
	DMA->CH7FLSAD = 0x00000000;
	DMA->CH7RAMAD = 0x00000000;
	DMA->CHSTATUS = 0x00000000;
}
//Code_End
          

void DMA_Init(DMA_InitTypeDef* para)
{
	if( DMA_CH7 == para->CHx )
	{
		DMA_CH7RAMAD_Write(para->CHxRAMAD);//CH0~CH7ͨRAMַָ
		DMA_CH7FLSAD_Write(para->CH7FLSAD);//ͨFLASHַָͨ7
	}
	else
	{
		DMA_CHxRAMAD_Write(para->CHx, para->CHxRAMAD);//CH0~CH7ͨRAMַָ
	}
	
	DMA_CHxCTRL_TSIZE_Set(para->CHx, para->CHxTSIZE);	//ͨ䳤
	DMA_CHxCTRL_PRI_Set(para->CHx, para->CHxPRI);		//ͨȼ
	DMA_CHxCTRL_INC_Set(para->CHx, para->CHxINC);		//ַͨ
	DMA_CHxCTRL_SSEL_Set(para->CHx, para->CHxSSEL);		//CH0~CH6ͨѡ,CH7䷽ʽѡ
	DMA_CHxCTRL_FTIE_Setable(para->CHx, para->CHxFTIE);	//ͨжʹ
	DMA_CHxCTRL_HTIE_Setable(para->CHx, para->CHxHTIE);	//ͨжʹ
	DMA_CHxCTRL_EN_Setable(para->CHx, para->CHxEN);		//ͨʹ
}

/******END OF FILE****/



