/**
  ******************************************************************************
  * @file    fm33g0xx_rcc.c
  * @author  FM33g0xx Application Team
  * @version V3.0.1G
  * @date    10-30-2018
  * @brief   This file provides firmware functions to manage the following 
  *          functionalities of the clock control (RCC) peripheral:
  *           + Internal/external clocks, PLL, CSS and MCO configuration
  *           + System, AHB and APB busses clocks configuration
  *           + Peripheral clocks configuration
  *           + Interrupts and flags management
  *
*/

/* Includes ------------------------------------------------------------------*/
#include "fm33g0xx_rcc.h" 

/** @addtogroup fm33g0xx_StdPeriph_Driver
  * @{
  */

/** @defgroup RCC 
  * @brief RCC driver modules
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/** @defgroup RCC_Private_Functions
  * @{
  */
 
 

/********************************
ģʽ¶RCLP
:ģʽ¶RCLP(Sleep/DeepSleepģʽ½ֹRCLP޾Ч)
:RCLP
1ģʽ¹رRCLP
0ģʽ±RCLP
********************************/
void RCC_SYSCLKSEL_LPM_RCLP_OFF_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		RCC->SYSCLKSEL |= (RCC_SYSCLKSEL_LPM_RCLP_OFF_Msk);
	}
	else
	{
		RCC->SYSCLKSEL &= ~(RCC_SYSCLKSEL_LPM_RCLP_OFF_Msk);
	}
}
/********************************
ȡģʽ¶RCLPź
:ȡģʽ¶RCLPĴ
:RCLP
1ģʽ¹رRCLP
0ģʽ±RCLP
********************************/
FunState RCC_SYSCLKSEL_LPM_RCLP_OFF_Getable(void)
{
	if (RCC->SYSCLKSEL & (RCC_SYSCLKSEL_LPM_RCLP_OFF_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
޾ģʽLSCLKʱԴѡ
:޾ģʽLSCLKʱԴѡ񣬣޾Ч)
: RCC_SYSCLKSEL_LSCKSEL_RCLP RCLP
      RCC_SYSCLKSEL_LSCKSEL_RCLF RCLF

********************************/
void RCC_SYSCLKSEL_LSCKSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->SYSCLKSEL;
	tmpreg &= ~(RCC_SYSCLKSEL_LSCKSEL_Msk);
	tmpreg |= (SetValue & RCC_SYSCLKSEL_LSCKSEL_Msk);
	RCC->SYSCLKSEL = tmpreg;
}

/********************************
ȡ޾ģʽLSCLKʱԴѡ
:ȡ޾ģʽLSCLKʱԴѡ
: 
RCC_SYSCLKSEL_LSCKSEL_RCLP RCLP
      RCC_SYSCLKSEL_LSCKSEL_RCLF RCLF
********************************/
uint32_t RCC_SYSCLKSEL_LSCKSEL_Get(void)
{
	return (RCC->SYSCLKSEL & RCC_SYSCLKSEL_LSCKSEL_Msk);
}

/********************************
Sleep/DeepSleepģʽEXTIú
:Sleep/DeepSleepģʽEXTI
:EXTI
1Sleep/DeepSleepģʽʹⲿжϲʱΪLSCLK
0Sleep/DeepSleepģʽ½ֹⲿжϲ޷EXTIжϣ
********************************/
void RCC_SYSCLKSEL_SLP_ENEXTI_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		RCC->SYSCLKSEL |= (RCC_SYSCLKSEL_SLP_ENEXTI_Msk);
	}
	else
	{
		RCC->SYSCLKSEL &= ~(RCC_SYSCLKSEL_SLP_ENEXTI_Msk);
	}
}
/********************************
ȡSleep/DeepSleepģʽEXTIú
:ȡSleep/DeepSleepģʽEXTI
:
1Sleep/DeepSleepģʽʹⲿжϲʱΪLSCLK
0Sleep/DeepSleepģʽ½ֹⲿжϲ޷EXTIжϣ
********************************/
FunState RCC_SYSCLKSEL_SLP_ENEXTI_Getable(void)
{
	if (RCC->SYSCLKSEL & (RCC_SYSCLKSEL_SLP_ENEXTI_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
EXTIж˲ʱѡ
:EXTIж˲ʱѡ
:EXTIж˲ʱѡ
RCC_SYSCLKSEL_EXTICKSEL_LSCLKⲿжʹLSCLK
RCC_SYSCLKSEL_EXTICKSEL_AHBCLKⲿжʹAHBCLK
********************************/
void RCC_SYSCLKSEL_EXTICKSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->SYSCLKSEL;
	tmpreg &= ~(RCC_SYSCLKSEL_EXTICKSEL_Msk);
	tmpreg |= (SetValue & RCC_SYSCLKSEL_EXTICKSEL_Msk);
	RCC->SYSCLKSEL = tmpreg;
}
/********************************
ȡEXTIж˲ʱѡ
:ȡEXTIж˲ʱӵѡ
:ȡEXTIж˲ʱѡ
RCC_SYSCLKSEL_EXTICKSEL_LSCLKⲿжʹLSCLK
RCC_SYSCLKSEL_EXTICKSEL_AHBCLKⲿжʹAHBCLK
********************************/
uint32_t RCC_SYSCLKSEL_EXTICKSEL_Get(void)
{
	return (RCC->SYSCLKSEL & RCC_SYSCLKSEL_EXTICKSEL_Msk);
}

/********************************
APBʱӷƵѡ
:APBʱӷƵѡ
:APBʱӷƵѡ
********************************/
void RCC_SYSCLKSEL_APBPRES_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->SYSCLKSEL;
	tmpreg &= ~(RCC_SYSCLKSEL_APBPRES_Msk);
	tmpreg |= (SetValue & RCC_SYSCLKSEL_APBPRES_Msk);
	RCC->SYSCLKSEL = tmpreg;
}

/********************************
ȡAPBʱӷƵѡ
:ȡAPBʱӷƵѡ
:APBʱӷƵѡ
********************************/
uint32_t RCC_SYSCLKSEL_APBPRES_Get(void)
{
	return (RCC->SYSCLKSEL & RCC_SYSCLKSEL_APBPRES_Msk);
}

/********************************
AHBʱӷƵѡ
:AHBʱӷƵѡ
:AHBʱӷƵѡ
********************************/
void RCC_SYSCLKSEL_AHBPRES_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->SYSCLKSEL;
	tmpreg &= ~(RCC_SYSCLKSEL_AHBPRES_Msk);
	tmpreg |= (SetValue & RCC_SYSCLKSEL_AHBPRES_Msk);
	RCC->SYSCLKSEL = tmpreg;
}
/********************************
ȡAHBʱӷƵѡ
:ȡAHBʱӷƵѡ
:AHBʱӷƵѡ
********************************/
uint32_t RCC_SYSCLKSEL_AHBPRES_Get(void)
{
	return (RCC->SYSCLKSEL & RCC_SYSCLKSEL_AHBPRES_Msk);
}


/********************************
ϵͳʱԴѡ
:ϵͳʱԴѡ
:ϵͳʱԴѡ
********************************/
void RCC_SYSCLKSEL_SYSCLKSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->SYSCLKSEL;
	tmpreg &= ~(RCC_SYSCLKSEL_SYSCLKSEL_Msk);
	tmpreg |= (SetValue & RCC_SYSCLKSEL_SYSCLKSEL_Msk);
	RCC->SYSCLKSEL = tmpreg;
}


/********************************
ȡϵͳʱԴѡ
:ȡϵͳʱԴѡ
:ϵͳʱԴѡ
********************************/
uint32_t RCC_SYSCLKSEL_SYSCLKSEL_Get(void)
{
	return (RCC->SYSCLKSEL & RCC_SYSCLKSEL_SYSCLKSEL_Msk);
}
/********************************
RCHFƵѡ
:RCHFƵѡ
:RCHFƵѡ
********************************/
void RCC_RCHFCON_FSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->RCHFCON;
	tmpreg &= ~(RCC_RCHFCON_FSEL_Msk);
	tmpreg |= (SetValue & RCC_RCHFCON_FSEL_Msk);
	RCC->RCHFCON = tmpreg;
}
/********************************
ȡRCHFƵѡ
:ȡRCHFƵѡ
:RCHFƵѡ
********************************/
uint32_t RCC_RCHFCON_FSEL_Get(void)
{
	return (RCC->RCHFCON & RCC_RCHFCON_FSEL_Msk);
}


/********************************
RCHFʹܺ
:RCHFʹ
:RCHFʹܵ
********************************/
void RCC_RCHFCON_RCHFEN_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		RCC->RCHFCON |= (RCC_RCHFCON_RCHFEN_Msk);
	}
	else
	{
		RCC->RCHFCON &= ~(RCC_RCHFCON_RCHFEN_Msk);
	}
}
/********************************
ȡRCHFʹܺ
:ȡRCHFʹܵ
:RCHFʹܵ
********************************/
FunState RCC_RCHFCON_RCHFEN_Getable(void)
{
	if (RCC->RCHFCON & (RCC_RCHFCON_RCHFEN_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
RCHFƵʵУ
:RCHFƵʵУ
:RCHFƵʵУֵ
********************************/
void RCC_RCHFTRIM_Write(uint32_t SetValue)
{
	RCC->RCHFTRIM = (SetValue & RCC_RCHFTRIM_RCHFTRIM_Msk);
}
/********************************
ȡRCHFƵʵУĺ
:ȡRCHFƵʵУֵ
:RCHFƵʵУֵ
********************************/
uint32_t RCC_RCHFTRIM_Read(void)
{
	return (RCC->RCHFTRIM & RCC_RCHFTRIM_RCHFTRIM_Msk);
}

/********************************
PLLƵ
:PLLƵ
:PLLƵ
********************************/
void RCC_PLLCON_PLLDB_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->PLLCON;
	tmpreg &= ~(RCC_PLLCON_PLLDB_Msk);
	tmpreg |= (SetValue & RCC_PLLCON_PLLDB_Msk);
	RCC->PLLCON = tmpreg;
}
/********************************
ȡPLLƵ
:ȡPLLƵ
:PLLƵ
********************************/
uint32_t RCC_PLLCON_PLLDB_Get(void)
{
	return (RCC->PLLCON & RCC_PLLCON_PLLDB_Msk);
}


/********************************
PLLѡ
:PLLѡ
:PLLѡ
********************************/
void RCC_PLLCON_PLLOSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->PLLCON;
	tmpreg &= ~(RCC_PLLCON_PLLOSEL_Msk);
	tmpreg |= (SetValue & RCC_PLLCON_PLLOSEL_Msk);
	RCC->PLLCON = tmpreg;
}

/********************************
ȡPLLѡ
:ȡPLLѡ
:PLLѡ
********************************/
uint32_t RCC_PLLCON_PLLOSEL_Get(void)
{
	return (RCC->PLLCON & RCC_PLLCON_PLLOSEL_Msk);
}

/********************************
PLLԴѡ
:PLLԴѡ
:PLLԴѡ
********************************/
void RCC_PLLCON_PLLINSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->PLLCON;
	tmpreg &= ~(RCC_PLLCON_PLLINSEL_Msk);
	tmpreg |= (SetValue & RCC_PLLCON_PLLINSEL_Msk);
	RCC->PLLCON = tmpreg;
}
/********************************
ȡPLLԴѡ
:ȡPLLԴѡ
:PLLԴѡ
********************************/
uint32_t RCC_PLLCON_PLLINSEL_Get(void)
{
	return (RCC->PLLCON & RCC_PLLCON_PLLINSEL_Msk);
}

/********************************
PLLʹѡ
:PLLʹѡ
:PLLʹܵ
********************************/
void RCC_PLLCON_PLLEN_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		RCC->PLLCON |= (RCC_PLLCON_PLLEN_Msk);
	}
	else
	{
		RCC->PLLCON &= ~(RCC_PLLCON_PLLEN_Msk);
	}
}
/********************************
ȡPLLʹѡ
:ȡPLLʹѡ
:PLLʹܵ
********************************/
FunState RCC_PLLCON_PLLEN_Getable(void)
{
	if (RCC->PLLCON & (RCC_PLLCON_PLLEN_Msk))
	{
		return ENABLE;
	}
	else
	{
		return DISABLE;
	}
}

/********************************
RCLPغ
:RCLPʹѡ
:RCLPʹܵ
********************************/
FlagStatus RCC_RCLPCON_RCLP_EN_B_Chk(void)
{
	if (RCC->RCLPCON & RCC_RCLPCON_RCLP_EN_B_Msk)
	{
		return SET;
	}
	else
	{
		return RESET;
	}
}


/********************************
RCLP̺
:RCLPƵ
:RCLPƵʵֵ
********************************/
void RCC_RCLPTRIM_Write(uint32_t SetValue)
{
	RCC->RCLPTRIM = (SetValue & RCC_RCLPTRIM_RCLPTRIM_Msk);
}
/********************************
ȡRCLPֵ
:ȡRCLPֵ
:RCLPƵʵֵ
********************************/
uint32_t RCC_RCLPTRIM_Read(void)
{
	return (RCC->RCLPTRIM & RCC_RCLPTRIM_RCLPTRIM_Msk);
}

/********************************
XTLFǿú
:XTLFѡ񣬵ԽǿԽ
:XTLF
********************************/
void RCC_XTLFIPW_XTLFIPW_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->XTLFIPW;
	tmpreg &= ~(RCC_XTLFIPW_XTLFIPW_Msk);
	tmpreg |= (SetValue & RCC_XTLFIPW_XTLFIPW_Msk);
	RCC->XTLFIPW = tmpreg;
}

/********************************
ȡXTLFǿú
:ȡXTLFѡ
:XTLF
********************************/
uint32_t RCC_XTLFIPW_XTLFIPW_Get(void)
{
	return (RCC->XTLFIPW & RCC_XTLFIPW_XTLFIPW_Msk);
}


/********************************
ADCʱѡ
:ADCʱѡ
ADCʱѡ
********************************/
void RCC_PERCLKCON2_ADCCKSEL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->PERCLKCON2;
	tmpreg &= ~(RCC_PERCLKCON2_ADCCKSEL_Msk);
	tmpreg |= (SetValue & RCC_PERCLKCON2_ADCCKSEL_Msk);
	RCC->PERCLKCON2 = tmpreg;
}
/********************************
ȡADCʱѡ
:ȡADCʱѡ
ADCʱѡ
********************************/
uint32_t RCC_PERCLKCON2_ADCCKSEL_Get(void)
{
	return (RCC->PERCLKCON2 & RCC_PERCLKCON2_ADCCKSEL_Msk);
}


/********************************
AHB Masterȼú
:AHB Masterȼ
룺AHB Masterȼõ
0DMA
1CPU
********************************/
void RCC_MPRIL_MPRIL_Set(uint32_t SetValue)
{
	uint32_t tmpreg;
	tmpreg = RCC->MPRIL;
	tmpreg &= ~(RCC_MPRIL_MPRIL_Msk);
	tmpreg |= (SetValue & RCC_MPRIL_MPRIL_Msk);
	RCC->MPRIL = tmpreg;
}

/********************************
ȡAHB Masterȼú
:ȡAHB Masterȼ
AHB Masterȼõ
********************************/
uint32_t RCC_MPRIL_MPRIL_Get(void)
{
	return (RCC->MPRIL & RCC_MPRIL_MPRIL_Msk);
}

/********************************
RCLFʹܺ
:RCLFʹֹܻ
룺ENABLEʹ
      DISABLEֹ

********************************/
void RCC_RCLFCON_RCLFENB_Setable(FunState NewState)
{
	if (NewState == ENABLE)
	{
		RCC->RCLFCON &= ~(RCC_RCLFCON_RCLFENB_Msk);
	}
	else
	{
		RCC->RCLFCON |= (RCC_RCLFCON_RCLFENB_Msk);
	}
}

/********************************
ȡRCLFʹ״̬
:ȡRCLFʹ״̬
룺
0: ʹ
      1ֹ
********************************/
FunState RCC_RCLFCON_RCLFENB_Getable(void)
{
	if (RCC->RCLFCON & (RCC_RCLFCON_RCLFENB_Msk))
	{
		return DISABLE;
	}
	else
	{
		return ENABLE;
	}
}

/********************************
дRCLFTRIMֵ
:дRCLFTRIMֵ
룺RCLF TRIMֵ

********************************/
void RCC_RCLFTRIM_Write(uint32_t SetValue)
{
	RCC->RCLFTRIM = (SetValue & RCC_RCLFTRIM_RCLFTRIM_Msk);
}

/********************************
RCLFTRIMֵ
ܣRCLFTRIMֵ
룺
RCLF TRIMֵ
********************************/
uint32_t RCC_RCLFTRIM_Read(void)
{
	return (RCC->RCLFTRIM & RCC_RCLFTRIM_RCLFTRIM_Msk);
}

/********************************
оƬʱĬϲú
:оƬʱĬϲ
********************************/
void RCC_Deinit(void)
{
	RCC->SYSCLKSEL = 0x02008300;
	RCC->RCHFCON = 0x00000001;
	//RCC->RCHFTRIM = 0x00000040;
	RCC->PLLCON = 0x01F30000;
	//RCC->RCLPCON = ;
	RCC->RCLPTRIM = 0x00000008;
	//RCC->XTLFIPW = 0x00000000;
	RCC->PERCLKCON1 = 0x80000058;
	RCC->PERCLKCON2 = 0x00060000;
	RCC->PERCLKCON3 = 0x00000000;
	RCC->PERCLKCON4 = 0x00000000;
	RCC->MPRIL = 0x80000000;
  RCC->RCLFCON = 0x00000000;
	//RCC->RCLFTRIM = 0x00000020;
}
//Code_End

/********************************
ȡоƬõĲͬʱƵʺ
:ȡоƬõĲͬʱƵ
RCHF_Frequency 
PLL_Frequency 
SYSCLK_Frequency 
AHBCLK_Frequency 
APBCLK_Frequency 
********************************/
void RCC_GetClocksFreq(RCC_ClocksType* para)
{
    uint32_t tmp32 = 0,tmp_value = 0;

	para->RCHF_Frequency = 0;
	para->PLL_Frequency = 0;
	para->SYSCLK_Frequency = 0;
	para->AHBCLK_Frequency = 0;
	para->APBCLK_Frequency = 0;
	
	/* Get RCHF FSEL */
	if(ENABLE == RCC_RCHFCON_RCHFEN_Getable())
	{
		tmp32 = RCC_RCHFCON_FSEL_Get();
		tmp32 = tmp32 >> RCC_RCHFCON_FSEL_Pos;  
		/* RCHF clock frequency */
		if(tmp32==0xf)
		{
			para->RCHF_Frequency = 36000000 ;	
		}
		else
		{
			para->RCHF_Frequency = __RCHF_INITIAL_CLOCK * (tmp32 + 1);
		}
	}

	if(ENABLE == RCC_PLLCON_PLLEN_Getable())
	{
		/* Get Pll frequency */
		tmp32 = RCC_PLLCON_PLLINSEL_Get();
		tmp32 = tmp32 >> RCC_PLLCON_PLLINSEL_Pos;
		switch(tmp32)
		{
			case 0x01: //01:RCLP
				tmp_value = __RCLP_CLOCK;
				break;
			case 0x02: //10:RCHF/256
				tmp_value = para->RCHF_Frequency/256;
				break;
			default: //00/11:XTLF
				tmp_value = __XTLF_CLOCK;
				break;
		}
		tmp32 = RCC_PLLCON_PLLDB_Get();
		tmp32 = tmp32 >> RCC_PLLCON_PLLDB_Pos;
		para->PLL_Frequency = (tmp32 + 1) * tmp_value;
		if( RCC_PLLCON_PLLOSEL_MUL2 == RCC_PLLCON_PLLOSEL_Get() )
		{
			para->PLL_Frequency = para->PLL_Frequency*2;
		}
	}
	
	/* Get SYSCLK source */
    tmp32 = RCC_SYSCLKSEL_SYSCLKSEL_Get();
    tmp32 = tmp32 >> RCC_SYSCLKSEL_SYSCLKSEL_Pos;
    switch (tmp32)
    {
        case 0x00:  /* RCHF used as system clock source */
            para->SYSCLK_Frequency = para->RCHF_Frequency;
            break;
        case 0x01:  /* RCLP used as system clock  source */
            para->SYSCLK_Frequency = __RCLF_CLOCK;
            break;
        case 0x02:  /* LSCLK used as system clock  source */
            para->SYSCLK_Frequency = __XTLF_CLOCK;
            break;
        case 0x03:  /* PLL used as system clock  source */
            para->SYSCLK_Frequency = para->PLL_Frequency;
            break;
        default:
            para->SYSCLK_Frequency = para->RCHF_Frequency;
            break;
    }
	
	/* Get AHB PRES */
    tmp32 = RCC_SYSCLKSEL_AHBPRES_Get();
    tmp32 = tmp32 >> RCC_SYSCLKSEL_AHBPRES_Pos;  
    switch(tmp32)
    {
        case 0x04: //100:DIV2
            para->AHBCLK_Frequency = para->SYSCLK_Frequency/2;
            break;
        case 0x05: //101:DIV4
            para->AHBCLK_Frequency = para->SYSCLK_Frequency/4;
            break;
        case 0x06: //110:DIV8
            para->AHBCLK_Frequency = para->SYSCLK_Frequency/8;
            break;
        case 0x07: //111:DIV16
            para->AHBCLK_Frequency = para->SYSCLK_Frequency/16;
            break;
        default: //0XX:DIV1
            para->AHBCLK_Frequency = para->SYSCLK_Frequency;
            break;
    }

	/* Get APB PRES */
    tmp32 = RCC_SYSCLKSEL_APBPRES_Get();
    tmp32 = tmp32 >> RCC_SYSCLKSEL_APBPRES_Pos; 
	/* APB clock frequency */
    switch(tmp32)
    {
        case 0x04: //100:DIV2
            para->APBCLK_Frequency = para->AHBCLK_Frequency/2;
            break;
        case 0x05: //101:DIV4
            para->APBCLK_Frequency = para->AHBCLK_Frequency/4;
            break;
        case 0x06: //110:DIV8
            para->APBCLK_Frequency = para->AHBCLK_Frequency/8;
            break;
        case 0x07: //111:DIV16
            para->APBCLK_Frequency = para->AHBCLK_Frequency/16;
            break;
        default: //0XX:DIV1
            para->APBCLK_Frequency = para->AHBCLK_Frequency;
            break;
    }
}

/********************************
ʱʹܺ
:ģҪĶӦʱӽʹ
룺periph_defⲿģ
      NewStateʹλ
 ********************************/
void RCC_PERCLK_SetableEx(uint32_t periph_def, FunState NewState)
{
	__IO uint32_t *p_reg = 0;
	uint32_t TempREG;
	
    switch((periph_def & 0x0F000000))
    {
		case 0x01000000:
			p_reg = &(RCC->PERCLKCON1);
			break;
		
		case 0x02000000:
			p_reg = &(RCC->PERCLKCON2);
			break;
		
		case 0x03000000:
			p_reg = &(RCC->PERCLKCON3);
			break;
		
		case 0x04000000:
			p_reg = &(RCC->PERCLKCON4);
			break;
		
		default:
			break;
    }
	if(p_reg)
	{
		periph_def &= 0x000000FF;
		TempREG = (0x1U << periph_def);
		
		if (NewState != DISABLE)
		{
			*p_reg |= TempREG;
		}
		else
		{
			*p_reg &= ~TempREG;
		}
	}
}

/********************************
RCHFʼ
:RCHFгʼ
룺RCHFƵʺʹ
 ********************************/
void RCC_RCHF_Init(RCC_RCHF_InitTypeDef* para)
{
	RCC_RCHFCON_FSEL_Set(para->FSEL);
	RCC_RCHFCON_RCHFEN_Setable(para->RCHFEN);
}

/********************************
PLLƵ
:PLLƵ
룺PLLƵ
 ********************************/
void RCC_PLLDB_WriteEx(uint32_t SetValue)
{	
	RCC_PLLCON_PLLDB_Set(SetValue<<RCC_PLLCON_PLLDB_Pos);
}
/********************************
ȡPLLƵ
:ȡPLLƵ
PLLƵ
 ********************************/
uint32_t RCC_PLLDB_ReadEx(void)
{
	uint32_t tmpreg;
	
	tmpreg = RCC_PLLCON_PLLDB_Get();
	return (tmpreg>>RCC_PLLCON_PLLDB_Pos);
}

/********************************
PLLʼ
:PLLгʼ
룺PLLõز
 ********************************/
void RCC_PLL_Init(RCC_PLL_InitTypeDef* para)
{
	RCC_PLLDB_WriteEx(para->PLLDB);
	RCC_PLLCON_PLLOSEL_Set(para->PLLOSEL);
	RCC_PLLCON_PLLINSEL_Set(para->PLLINSEL);
	RCC_PLLCON_PLLEN_Setable(para->PLLEN);
}

/* ϵͳʱӳʼ */
void RCC_SysClk_Init(RCC_SYSCLK_InitTypeDef* para)
{
	RCC_SYSCLKSEL_SYSCLKSEL_Set(para->SYSCLKSEL);
	RCC_SYSCLKSEL_AHBPRES_Set(para->AHBPRES);
	RCC_SYSCLKSEL_APBPRES_Set(para->APBPRES);
	RCC_SYSCLKSEL_EXTICKSEL_Set(para->EXTICKSEL);
	RCC_SYSCLKSEL_SLP_ENEXTI_Setable(para->SLP_ENEXTI);
	RCC_SYSCLKSEL_LPM_RCLP_OFF_Setable(para->LPM_RCLP_OFF);
}

/********************************
rchfУ׼ֵ뺯
:rchfУ׼ֵ(rchfУ׼ֵ(оƬλԶ8MУ׼ֵ))
룺ҪõRCHFƵ
			ClkMode 1 = 8M
			ClkMode 2 = 16M
			ClkMode 3 = 24M
			ClkMode 4 = 32M
 ********************************/
void RCC_Init_RCHF_Trim( uint8_t ClkMode )
{
	uint32_t Temp32;
	
	if( ClkMode == 1 )	//8M
	{
		Temp32 = const_rchf_Trim8;
	}
	else if( ClkMode == 2 )//16M
	{
		Temp32 = const_rchf_Trim16;
	}
	else if( ClkMode == 3 )//24M
	{
		Temp32 = const_rchf_Trim24;
	}
	else if( ClkMode == 4 )//36M
	{
		Temp32 = const_rchf_Trim36;
	}
	else//Ĭ8M
	{
		Temp32 = const_rchf_Trim8;
	}
	
	if( ((Temp32>>16)&0x0000FFFF) == ((~Temp32)&0x0000FFFF) )	//Уж
	{
		RCC_RCHFTRIM_Write(Temp32&0x0000007F);
	}	
	else
	{
		RCC_RCHFTRIM_Write(0x00000040);
	}
}

/******END OF FILE****/
